@@ -4,7 +4,7 @@
  * (C) Copyright 2013-2022 John E. Stone
  * SPDX-License-Identifier: BSD-3-Clause
  *
- * $Id: knot.cpp,v 1.6 2022/03/23 06:41:57 johns Exp $
+ * $Id: knot.cpp,v 1.8 2022/04/04 05:01:24 johns Exp $
  *
  */
 
@@ -275,14 +275,13 @@ rt->set_bg_mode(TachyonOptiX::RT_BACKGROUND_TEXTURE_SKY_SPHERE);
 //  rt->set_camera_type(TachyonOptiX::RT_ORTHOGRAPHIC);
 
   float campos[3] = {0.0f, 10.0f, 12.0f};
-  float camU[3]   = {1.0f,  0.0f,  0.0f};
-  float camV[3]   = {0.0f, -1.0f,  0.0f};
-  float camW[3]   = {0.0f,  0.0f,  1.0f};
+//  float camU[3]   = {1.0f,  0.0f,  0.0f};
+  float camV[3]   = {0.0f,  1.0f,  0.0f};
+//  float camW[3]   = {0.0f,  0.0f,  1.0f};
+  float camat[3]  = {0.0f,  0.0f,  0.0f};
 
   rt->set_camera_pos(campos);
-  rt->set_camera_ONB(camU, camV, camW);
-
-  float camat[3]   = {0.f, 0.f, 0.f};
+//  rt->set_camera_ONB(camU, camV, camW);
   rt->set_camera_lookat(camat, camV);
 
   rt->set_camera_zoom(0.5f);
@@ -307,7 +306,7 @@ rt->set_bg_mode(TachyonOptiX::RT_BACKGROUND_TEXTURE_SKY_SPHERE);
   //
   int mat = 0;
   int mat2 = 1;
-  float ambient = 0.1f;
+  float ambient = 0.0f;
   float diffuse = 0.7f;
   float specular = 0.0f;
   float shininess = 0.0f;
@@ -384,6 +383,8 @@ printf("Writing rgba4u alpha channel output image 2\n");
         printf("Failed to write image '%s'!!\n", filename);
     }
 #else
+    stbi_flip_vertically_on_write(1);
+
     stbi_write_png(filename, imgSize[0], imgSize[1], 4, rgb4u, imgSize[0] * sizeof(int));
 #endif
 
