@@ -4,7 +4,7 @@
  * (C) Copyright 2013-2022 John E. Stone
  * SPDX-License-Identifier: BSD-3-Clause
  *
- * $Id: objloader.cpp,v 1.4 2022/03/23 04:58:26 johns Exp $
+ * $Id: objloader.cpp,v 1.11 2022/04/19 02:54:21 johns Exp $
  *
  */
 
@@ -12,7 +12,9 @@
  *  \file objloader.cpp
  *  \brief Loader for Wavefront OBJ scenes, using the "tiny_obj_loader"
  *         header-only loader library.
- *
+ *     
+ *         The Wavefront OBJ file format is described in detail here:     
+ *           http://paulbourke.net/dataformats/mtl/
  */
 
 //
@@ -150,23 +152,30 @@ int main(int argc, const char **argv) {
   int imgSize[2] = {3840, 2160 }; // W x H
   const char *objfilename = NULL;
   int ambientocclusion = 1;
+  int denoiser = 0;
+  int dof = 0;
   int warmup = 0; 
 
+  printf("Tachyon OBJ scene viewer demo\n");
+
   //
   // camera defaults
   //
-#if 0
-  float cam_pos[] =  {0.0f,  -6.0f,   -8.0f};   // look at origin from -Z
-  float cam_up[] =   {0.0f,   1.0f,    0.0f};	// Y-up
-  float cam_view[3];
 
-  // look at origin
-  float invlen = 1.0f / sqrtf(cam_pos[0]*cam_pos[0] +
-                              cam_pos[1]*cam_pos[1] +
-                              cam_pos[2]*cam_pos[2]);
-  cam_view[0] = -cam_pos[0] * invlen;
-  cam_view[1] = -cam_pos[1] * invlen;
-  cam_view[2] = -cam_pos[2] * invlen;
+#if 0
+  // XXX some default camera settings for the "San Miguel" test scene.
+  float campos[3] = {  22.0f,   14.0f,   10.0f};
+  float camV[3]   = {   0.0f,    1.0f,    0.0f};
+  float camat[3]  = {  10.0f,    0.0f,    0.0f};
+  float camzoom   = 0.5f;
+  float aomaxdist = 15;
+#else
+  // XXX some default camera settings for the "Sponza" test scene.
+  float campos[3] = { 800.0f,  400.0f,    0.0f};
+  float camV[3]   = {   0.0f,    1.0f,    0.0f};
+  float camat[3]  = {   0.0f,  400.0f,    0.0f};
+  float camzoom   = 0.5f;
+  float aomaxdist = 700;
 #endif
 
   // 
@@ -186,13 +195,55 @@ int main(int argc, const char **argv) {
 
   // parse remaining optional parameter flags
   if (argc > 2) {
-    for (int i=4; i<argc; i++) {
+    for (int i=2; i<argc; i++) {
       if (!strcmp("-ao", argv[i])) {
         ambientocclusion = 1;
         printf("Enabling renderer-specific AO lighting.\n");
         continue;
       }
 
+      if (!strcmp("-camlookat", argv[i])) {
+        if ((argc - i) >= 3) {
+          camat[0] = atof(argv[++i]);
+          camat[1] = atof(argv[++i]);
+          camat[2] = atof(argv[++i]);
+        }
+        continue;
+      }
+
+      if (!strcmp("-campos", argv[i])) {
+        if ((argc - i) >= 3) {
+          campos[0] = atof(argv[++i]);
+          campos[1] = atof(argv[++i]);
+          campos[2] = atof(argv[++i]);
+        }
+        continue;
+      }
+
+      if (!strcmp("-camup", argv[i])) {
+        if ((argc - i) >= 3) {
+          camV[0] = atof(argv[++i]);
+          camV[1] = atof(argv[++i]);
+          camV[2] = atof(argv[++i]);
+        }
+        continue;
+      }
+
+      if (!strcmp("-camzoom", argv[i])) {
+        if ((argc - i) >= 1) {
+          camzoom = atof(argv[++i]);
+        }
+        continue;
+      }
+
+      if (!strcmp("-aomaxdist", argv[i])) {
+        if ((argc - i) >= 1) {
+          aomaxdist = atof(argv[++i]);
+        }
+        printf("** aomaxdist: %.2f\n", aomaxdist);
+        continue;
+      }
+
       if (!strcmp("-noao", argv[i])) {
         ambientocclusion = 0;
         printf("Disabling renderer-specific AO lighting.\n");
@@ -208,6 +259,16 @@ int main(int argc, const char **argv) {
         continue;
       }
 
+      if (!strcmp("-denoiser", argv[i])) {
+        denoiser = 1;
+        continue;
+      }
+
+      if (!strcmp("-dof", argv[i])) {
+        dof = 1;
+        continue;
+      }
+
 #if 0
       if (!strcmp("-pause", argv[i])) {
         sleep(10);
@@ -224,6 +285,7 @@ int main(int argc, const char **argv) {
     }
   } 
 
+  printf("All command line flags processed.\n");
 
 #if defined(TACHYON_USEPINNEDMEMORY)
   printf("USING PINNED HOST MEMORY ALLOCATIONS\n");
@@ -263,10 +325,12 @@ int main(int argc, const char **argv) {
   auto& materials = reader.GetMaterials();
 
   printf("OBJ materials: %ld\n", materials.size());
+#if 0
   for (size_t m = 0; m < materials.size(); m++) {
     printf("  mat[%ld]: '%s'\n", m, materials[m].name.c_str());
   } 
   printf("\n");
+#endif
 
   printf("OBJ shapes: %ld\n", shapes.size());
 #if 0
@@ -342,12 +406,12 @@ rt->set_bg_mode(TachyonOptiX::RT_BACKGROUND_TEXTURE_SKY_SPHERE);
 
   if (ambientocclusion) {
     rt->set_ao_samples(1);
-    rt->set_ao_ambient(1.0);
-    rt->set_ao_direct(0.2);
-    rt->set_ao_maxdist(600.2);
+    rt->set_ao_ambient(1.2);
+    rt->set_ao_direct(0.4);
+    rt->set_ao_maxdist(aomaxdist);
   }
 
-  float lightdir0[] = { -0.5f, 0.5f, -1.0f };
+  float lightdir0[] = {  0.3f, 1.0f,  0.3f };
   float lightcolor0[] = { 1.0f, 1.0f, 1.0f };
   rt->add_directional_light(lightdir0, lightcolor0);
 
@@ -357,24 +421,18 @@ rt->set_bg_mode(TachyonOptiX::RT_BACKGROUND_TEXTURE_SKY_SPHERE);
 //  rt->set_camera_type(TachyonOptiX::RT_EQUIRECTANGULAR);
 //  rt->set_camera_type(TachyonOptiX::RT_OCTOHEDRAL);
 
-
-  //
-  // XXX some default camera settings for the 
-  //     "Sponza" test scene.
-  //
-  float campos[3] = {1200.f, 600.0f, 0.0f};
-  float camU[3]   = {0.0f, 0.0f,  1.0f};
-  float camV[3]   = {0.0f, -1.0f, 0.0f};
-  float camW[3]   = {-1.0f, 0.0f, 0.0f};
-
   rt->set_camera_pos(campos);
-  rt->set_camera_ONB(camU, camV, camW);
+//  rt->set_camera_ONB(camU, camV, camW);
+  rt->set_camera_lookat(camat, camV);
+  rt->set_camera_zoom(camzoom);
 
-  rt->set_camera_zoom(0.5f);
+  if (denoiser)
+    rt->denoiser_enable(1);
 
-  rt->denoiser_enable(1);
-  rt->camera_dof_enable(1);
-  rt->set_camera_dof_fnumber(60.0f);
+  if (dof)
+    rt->camera_dof_enable(1);
+
+  rt->set_camera_dof_fnumber(80.0f);
   rt->set_camera_dof_focal_dist(500.0f);
 
   // set stereoscopic display parameters
@@ -494,7 +552,9 @@ rt->set_bg_mode(TachyonOptiX::RT_BACKGROUND_TEXTURE_SKY_SPHERE);
     }
 
     if (img != NULL) {
-      rt->add_tex2d_rgba4u(img, xres, yres, RT_COLORSPACE_sRGB, m);
+      int texflags = (chinfile == 4) ? RT_TEX_ALPHA : RT_TEX_NONE;
+
+      rt->add_tex2d_rgba4u(img, xres, yres, texflags | RT_COLORSPACE_sRGB, m);
 
       rt->add_material_textured(ambient, diffuse, specular, 
                                 shininess, reflectivity, opacity, 
@@ -660,6 +720,8 @@ printf("Writing rgba4u alpha channel output image 2\n");
         printf("Failed to write image '%s'!!\n", filename);
     }
 #else
+    stbi_flip_vertically_on_write(1);
+
     stbi_write_png(filename, imgSize[0], imgSize[1], 4, rgb4u, imgSize[0] * sizeof(int));
 #endif
   
