@@ -4,7 +4,7 @@
  * (C) Copyright 2013-2022 John E. Stone
  * SPDX-License-Identifier: BSD-3-Clause
  *
- * $Id: parametric.cpp,v 1.8 2022/03/23 06:41:57 johns Exp $
+ * $Id: parametric.cpp,v 1.11 2022/04/04 05:01:24 johns Exp $
  *
  */
 
@@ -607,7 +607,14 @@ void gen_spheresurf(TachyonOptiX *rt, int udiv, int vdiv,
   float3 *cols = spheres.primcolors3f.data();
 
   memcpy(verts, coords, numpts * 3 * sizeof(float));
-  memcpy(cols, colors, numpts * 3 * sizeof(float));
+  
+  if (colors != NULL) {
+    memcpy(cols, colors, numpts * 3 * sizeof(float));
+  } else {
+    for (int i=0; i<numpts; i++) {
+      cols[i]=make_float3(0.3f, 0.3f, 0.3f);
+    }
+  }
   for (int i=0; i<numpts; i++)
     radii[i]=radius;   
 
@@ -622,7 +629,7 @@ void gen_spheresurf(TachyonOptiX *rt, int udiv, int vdiv,
 void gen_wiremesh(TachyonOptiX *rt, int udiv, int vdiv, int wrapmesh,
                   float *coords, float radius, float *colors, 
                   int *wiremesh_indices, int mat) {
-  int numpts = udiv * vdiv;
+//  int numpts = udiv * vdiv;
 
   // if we're not doing wraparound, don't generate associated connections 
   int umax = (wrapmesh) ? udiv : (udiv-1);
@@ -630,25 +637,26 @@ void gen_wiremesh(TachyonOptiX *rt, int udiv, int vdiv, int wrapmesh,
   int numedges = umax * vmax;
 
   CylinderArray cyls;
-  cyls.start.resize(numedges);
-  cyls.end.resize(numedges);
-  cyls.radius.resize(numedges);
-  cyls.primcolors3f.resize(numedges);
+  cyls.start.resize(numedges*2);
+  cyls.end.resize(numedges*2);
+  cyls.radius.resize(numedges*2);
+  cyls.primcolors3f.resize(numedges*2);
 
   float3 *vstart = cyls.start.data();
-  float3 *vend = cyls.start.data();
+  float3 *vend = cyls.end.data();
   float *vrad = cyls.radius.data();
   float3 *cols = cyls.primcolors3f.data(); 
 
-  memcpy(vstart, coords, numpts * 3 * sizeof(float));
-
-  for (int i=0; i<numedges; i++) {
-    int idx1 = 3 * wiremesh_indices[i*2];
+  for (int i=0; i<numedges*2; i++) {
+    int idx1 = 3 * wiremesh_indices[i*2  ];
     int idx2 = 3 * wiremesh_indices[i*2+1];
     vstart[i] = make_float3(coords[idx1], coords[idx1+1], coords[idx1+2]);
-    vend[i] = make_float3(coords[idx2], coords[idx2+1], coords[idx2+2]);
-    vrad[i] = radius;
-    cols[i] = make_float3(colors[idx1], colors[idx1+1], colors[idx1+2]);
+    vend[i]   = make_float3(coords[idx2], coords[idx2+1], coords[idx2+2]);
+    vrad[i]   = radius;
+    if (colors) 
+      cols[i] = make_float3(colors[idx1], colors[idx1+1], colors[idx1+2]);
+    else
+      cols[i] = make_float3(0.0f, 0.0f, 0.0f);
   }
 
   rt->add_cylarray(cyls, mat);
@@ -975,15 +983,14 @@ rt->set_bg_mode(TachyonOptiX::RT_BACKGROUND_TEXTURE_SKY_SPHERE);
   rt->set_camera_type(TachyonOptiX::RT_PERSPECTIVE);
 //  rt->set_camera_type(TachyonOptiX::RT_ORTHOGRAPHIC);
 
-  float campos[3] = {0.f, 10.0f, 12.f};
-  float camU[3]   = {1.0f, 0.0f, 0.0f};
-  float camV[3]   = {0.0f, -1.0f, 0.0f};
-  float camW[3]   = {0.0f,  0.0f, 1.0f};
+  float campos[3] = {0.0f, 10.0f, 12.f};
+//  float camU[3]   = {1.0f,  0.0f,  0.0f};
+  float camV[3]   = {0.0f,  1.0f,  0.0f};
+//  float camW[3]   = {0.0f,  0.0f,  1.0f};
+  float camat[3]  = {0.0f,  0.0f,  0.0f};
 
   rt->set_camera_pos(campos);
-  rt->set_camera_ONB(camU, camV, camW);
-
-  float camat[3]   = {0.f, 0.f, 0.f};
+//  rt->set_camera_ONB(camU, camV, camW);
   rt->set_camera_lookat(camat, camV);
 
   rt->set_camera_zoom(0.5f);
@@ -1003,7 +1010,7 @@ rt->set_bg_mode(TachyonOptiX::RT_BACKGROUND_TEXTURE_SKY_SPHERE);
   rt->set_cue_mode(TachyonOptiX::RT_FOG_NONE, start, end, density);
 
   int mat = 0;
-  float ambient = 0.1f;
+  float ambient = 0.0f;
   float diffuse = 0.7f;
   float specular = 0.0f;
   float shininess = 0.0f;
@@ -1038,7 +1045,8 @@ rt->set_bg_mode(TachyonOptiX::RT_BACKGROUND_TEXTURE_SKY_SPHERE);
   PROFILE_PUSH_RANGE("Generate Scene", 0);
   if (!nospheres) {
     // Draw points on parametric surface using spheres
-    gen_spheresurf(rt, udiv, vdiv, coords, radius, (wireframe) ? NULL : colors, mat);
+    gen_spheresurf(rt, udiv, vdiv, coords, radius, 
+                   (wireframe) ? NULL : colors, mat);
   }
 
   if (!nosurf) {
@@ -1093,6 +1101,8 @@ printf("Writing rgba4u alpha channel output image 2\n");
         printf("Failed to write image '%s'!!\n", filename);
     }
 #else
+    stbi_flip_vertically_on_write(1);
+
     stbi_write_png(filename, imgSize[0], imgSize[1], 4, rgb4u, imgSize[0] * sizeof(int));
 #endif
   
