@@ -4,7 +4,7 @@
  * (C) Copyright 1994-2022 John E. Stone
  * SPDX-License-Identifier: BSD-3-Clause
  *
- * $Id: parse.h,v 1.34 2022/02/18 18:18:36 johns Exp $
+ * $Id: parse.h,v 1.35 2022/04/01 15:43:11 johns Exp $
  *
  */
 
@@ -70,7 +70,7 @@ static errcode GetCylinder(parsehandle *, SceneHandle);
 static errcode GetFCylinder(parsehandle *, SceneHandle);
 static errcode GetPolyCylinder(parsehandle *, SceneHandle);
 static errcode GetSphere(parsehandle *, SceneHandle);
-static errcode GetSphereArray(parsehandle *, SceneHandle);
+/* static errcode GetSphereArray(parsehandle *, SceneHandle); */
 static errcode GetPlane(parsehandle *, SceneHandle);
 static errcode GetRing(parsehandle *, SceneHandle);
 static errcode GetBox(parsehandle *, SceneHandle);
