@@ -4,7 +4,7 @@
  * (C) Copyright 2013-2022 John E. Stone
  * SPDX-License-Identifier: BSD-3-Clause
  *
- * $Id: TachyonOptiX.h,v 1.55 2022/03/22 20:29:50 johns Exp $
+ * $Id: TachyonOptiX.h,v 1.57 2022/04/19 02:54:24 johns Exp $
  *
  */
 
@@ -602,12 +602,12 @@ struct TachyonInstanceGroup {
   std::vector<TriangleMesh> trimeshes;
 
   // GASes get rebuilt upon any group geometry changes
-  std::vector<HGRecordGroup> sbtHGRecGroups;
-  CUMemBuf custprimsGASBuffer;             ///< final, compacted GAS
+  std::vector<HGRecordGroup> sbtHGRecGroups; ///< all GeomSBTHG recs
+  CUMemBuf custprimsGASBuffer;               ///< final, compacted GAS
 #if OPTIX_VERSION >= 70100
-  CUMemBuf curvesGASBuffer;                ///< final, compacted GAS
+  CUMemBuf curvesGASBuffer;                  ///< final, compacted GAS
 #endif
-  CUMemBuf trimeshesGASBuffer;             ///< final, compacted GAS
+  CUMemBuf trimeshesGASBuffer;               ///< final, compacted GAS
 
   std::vector<float *> transforms;
 };
@@ -734,7 +734,9 @@ private:
 
   std::vector<TachyonInstanceGroup> sceneinstancegroups;
 
-  std::vector<HGRecordGroup> hitgroupRecordGroups;
+  int sync_hitgroupRecordGroups; ///< sync host+GPU copies of HG recs
+  std::vector<HGRecordGroup> hitgroupRecordGroups; // all GeomSBTHG recs
+
   CUMemBuf hitgroupRecordsBuffer;
   OptixShaderBindingTable sbt = {};
 
@@ -974,9 +976,14 @@ private:
 
   /// Shader binding table management routines
   int regen_optix_sbt;
-  void context_create_SBT(void);
-  void context_clear_SBT(void);   ///< clear SBT, but retain persistent storage
-  void context_destroy_SBT(void); ///< completely deallocate SBT storage
+  void SBT_create_programs(void);
+  void SBT_create_hitgroups(void);
+  void SBT_clear(void);   ///< clear SBT, but retain persistent storage
+  void SBT_destroy(void); ///< completely deallocate SBT storage
+
+  /// update per-geom hitgroup flags for material or other cached values
+  void SBT_update_hitgroup_geomflags(void);
+
 
   // 
   // AABB calc helpers
@@ -1186,11 +1193,11 @@ public:
 
   /// define image to be used in a texture map
   int add_tex2d_rgba4u(const unsigned char *img, int xres, int yres, 
-                       int colorspace, int userindex);
+                       int texflags, int userindex);
 
   /// define image to be used in a texture map
   int add_tex3d_rgba4u(const unsigned char *img, int xres, int yres, int zres,
-                       int colorspace, int userindex);
+                       int texflags, int userindex);
 
   /// locate material via user index
   int material_index_from_user_index(int userindex); 
