@@ -5,7 +5,7 @@
  * (C) Copyright 1994-2022 John E. Stone
  * SPDX-License-Identifier: BSD-3-Clause
  *
- * $Id: api.c,v 1.208 2022/02/18 17:55:28 johns Exp $
+ * $Id: api.c,v 1.210 2022/03/13 23:30:01 johns Exp $
  *
  */
 
@@ -489,28 +489,51 @@ void rt_set_numthreads(SceneHandle voidscene, int numthreads) {
 
 void rt_background(SceneHandle voidscene, apicolor col) {
   scenedef * scene = (scenedef *) voidscene;
-  scene->bgtex.background.r = col.r;
-  scene->bgtex.background.g = col.g;
-  scene->bgtex.background.b = col.b;
+  scene->bgtex.bg_color.r = col.r;
+  scene->bgtex.bg_color.g = col.g;
+  scene->bgtex.bg_color.b = col.b;
 }
 
-void rt_background_gradient(SceneHandle voidscene, 
-  apivector up,
-  flt topval, flt botval, apicolor topcol, apicolor botcol) {
+void rt_background_gradient(SceneHandle voidscene, apivector up,
+                            flt topval, flt botval, 
+                            apicolor topcol, apicolor botcol) {
+  apicolor delta;
+  flt maxcoldelta;
   scenedef * scene = (scenedef *) voidscene;
 
-  scene->bgtex.gradient = up;
+  scene->bgtex.bg_grad_top.r = topcol.r;  
+  scene->bgtex.bg_grad_top.g = topcol.g;  
+  scene->bgtex.bg_grad_top.b = topcol.b;
 
-  scene->bgtex.gradtopval = topval;
-  scene->bgtex.gradbotval = botval;
+  scene->bgtex.bg_grad_bot.r = botcol.r;  
+  scene->bgtex.bg_grad_bot.g = botcol.g;  
+  scene->bgtex.bg_grad_bot.b = botcol.b;
 
-  scene->bgtex.backgroundtop.r = topcol.r;  
-  scene->bgtex.backgroundtop.g = topcol.g;  
-  scene->bgtex.backgroundtop.b = topcol.b;
+  scene->bgtex.bg_grad_updir  = up;
+  scene->bgtex.bg_grad_topval = topval;
+  scene->bgtex.bg_grad_botval = botval;
+  scene->bgtex.bg_grad_invrange = 1.0 / (topval - botval);
 
-  scene->bgtex.backgroundbot.r = botcol.r;  
-  scene->bgtex.backgroundbot.g = botcol.g;  
-  scene->bgtex.backgroundbot.b = botcol.b;
+  /*
+   * Add noise to gradient backgrounds to prevent Mach banding effects,
+   * particularly noticable in video streams or movie renderings.
+   * Compute the delta between the top and bottom gradient colors and
+   * calculate the noise magnitude required, such that by adding it to the
+   * scalar interpolation parameter we get more than +/-1ulp in the
+   * resulting interpolated color, as represented in an 8bpp framebuffer.
+   */
+  delta.r = fabs(topcol.r - botcol.r);
+  delta.g = fabs(topcol.g - botcol.g);
+  delta.b = fabs(topcol.b - botcol.b);
+  maxcoldelta = (delta.r > delta.g) ? 
+                   ((delta.r > delta.b) ? delta.r : delta.b) :
+                   ((delta.g > delta.b) ? delta.g : delta.b);
+
+  /*
+   * Ideally the noise mag calc would take into account both max color delta
+   * and image dimensions to avoid banding even with very subtle gradients.
+   */
+  scene->bgtex.bg_grad_noisemag = (3.0f/256.0f) / (maxcoldelta + 0.0005);
 }
 
 void rt_background_sky_sphere(SceneHandle voidscene, apivector up, flt topval, 
