@@ -1,19 +1,25 @@
 /*
- *  imageio.h - This file deals with reading/writing image files 
+ * imageio.h - This file deals with reading/writing image files 
+ *
+ * (C) Copyright 1994-2022 John E. Stone
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * $Id: imageio.h,v 1.10 2022/02/18 17:55:28 johns Exp $
  *
- *  $Id: imageio.h,v 1.8 2008/06/02 05:30:52 johns Exp $
  */ 
 
-/* For our puposes, we're interested only in the 3 byte per pixel 24 bit
-   truecolor sort of file.. */
+/*
+ * For our puposes, we're interested only in the 3 byte per pixel 24 bit
+ * truecolor sort of file.. 
+ */
 
-#define IMAGENOERR     0  /* no error */
-#define IMAGEBADFILE   1  /* can't find or can't open the file */
-#define IMAGEUNSUP     2  /* the image file is an unsupported format */
-#define IMAGEALLOCERR  3  /* not enough remaining memory to load this image */
-#define IMAGEREADERR   4  /* failed read, short reads etc */
-#define IMAGEWRITEERR  5  /* failed write, short writes etc */
-#define IMAGENULLDATA  6  /* image to write was a null pointer */
+#define IMAGENOERR     0  /**< no error */
+#define IMAGEBADFILE   1  /**< can't find or can't open the file */
+#define IMAGEUNSUP     2  /**< the image file is an unsupported format */
+#define IMAGEALLOCERR  3  /**< not enough remaining memory to load this image */
+#define IMAGEREADERR   4  /**< failed read, short reads etc */
+#define IMAGEWRITEERR  5  /**< failed write, short writes etc */
+#define IMAGENULLDATA  6  /**< image to write was a null pointer */
 
 int readimage(rawimage *);
 int writeimage(char * name, int xres, int yres, 
