@@ -1,7 +1,11 @@
 /* 
  * shade.h - This file contains declarations and definitions for the shader.
  *
- *  $Id: shade.h,v 1.17 2003/02/16 06:24:21 johns Exp $
+ * (C) Copyright 1994-2022 John E. Stone
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * $Id: shade.h,v 1.20 2022/02/18 17:55:28 johns Exp $
+ *
  */
 
 #ifndef SHADE_H
@@ -15,13 +19,14 @@ color shade_reflection(ray *, const shadedata *, flt);
 color shade_transmission(ray *, const shadedata *, flt);
 
 
-
+color shade_ambient_occlusion(ray * incident, const shadedata * shadevars);
 flt shade_phong(const ray * incident, const shadedata * shadevars, flt specpower);
 flt shade_nullphong(const ray * incident, const shadedata * shadevars, flt specpower);
 flt shade_blinn(const ray * incident, const shadedata * shadevars, flt specpower);
 flt shade_blinn_fast(const ray * incident, const shadedata * shadevars, flt specpower);
 
 
+color fog_color(const ray * incident, color col, flt t);
 color fog_color_linear(struct fogdata_t *, color col, flt z);
 color fog_color_exp(struct fogdata_t *, color col, flt z);
 color fog_color_exp2(struct fogdata_t *, color col, flt z);
