@@ -1,11 +1,15 @@
 /* 
- * tgafile.h - this file contains defines and structures for tgafile.c
+ * tgafile.h - this file contains fctn prototypes for Targa image parsing
+ *
+ * (C) Copyright 1994-2022 John E. Stone
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * $Id: tgafile.h,v 1.10 2022/02/18 17:55:28 johns Exp $
  *
- *  $Id: tgafile.h,v 1.8 1999/09/01 18:40:05 johns Exp $
  */
 
 /* declare other functions */
-void createtgafile(char *, unsigned short, unsigned short);
+int createtgafile(char *, unsigned short, unsigned short);
 void * opentgafile(char *);
 void writetgaregion(void *, int, int, int, int, unsigned char *);
 void closetgafile(void *);
