@@ -5,7 +5,7 @@
  * (C) Copyright 1994-2022 John E. Stone
  * SPDX-License-Identifier: BSD-3-Clause
  *
- * $Id: trace.c,v 1.144 2022/02/18 17:55:28 johns Exp $
+ * $Id: trace.c,v 1.145 2022/03/14 03:50:38 johns Exp $
  *
  */
 
@@ -330,15 +330,16 @@ void * thread_trace(thr_parms * t) {
         for (tpxl=mystart; tpxl<=myend; tpxl++) {
           int y = tpxl / scene->hres;
           int x = tpxl - (y*scene->hres);
-
+          unsigned int idx = y*scene->hres + x;  /* 1-D pixel index */
 #if defined(RT_ACCUMULATE_ON)
           if (scene->accum_count) {
-            primary.randval =  tea4(x + (y*scene->hres), scene->accum_count);
+            primary.randval =  tea4(idx, scene->accum_count);
           }
 #endif
 
           int addr = hsize * y + (3 * (startx - 1 + x));  /* row address */
 
+          primary.idx = idx;        /* used for idx-based RNG seeding */
           primary.frng = cachefrng; /* each pixel uses the same AO RNG seed */
           col=scene->camera.cam_ray(&primary, x, y);  /* generate ray */ 
 
@@ -370,12 +371,14 @@ void * thread_trace(thr_parms * t) {
     for (y=starty; y<=stopy; y+=yinc) {
       int addr = hsize * (y - 1) + (3 * (startx - 1));  /* row address */
       for (x=startx; x<=stopx; x+=xinc,addr+=hskip) {
+        unsigned int idx = y*scene->hres + x;  /* 1-D pixel index */
 #if defined(RT_ACCUMULATE_ON)
         if (scene->accum_count) {
-          primary.randval =  tea4(x + (y*scene->hres), scene->accum_count);
+          primary.randval =  tea4(idx, scene->accum_count);
         }
 #endif
 
+        primary.idx = idx;        /* used for idx-based RNG seeding */
         primary.frng = cachefrng; /* each pixel uses the same AO RNG seed */
         col=scene->camera.cam_ray(&primary, x, y);  /* generate ray */ 
 
@@ -429,15 +432,17 @@ void * thread_trace(thr_parms * t) {
         for (tpxl=mystart; tpxl<=myend; tpxl++) {
           int y = tpxl / scene->hres;
           int x = tpxl - (y*scene->hres);
+          unsigned int idx = y*scene->hres + x;  /* 1-D pixel index */
 
           addr = hsize * y + (3 * (startx - 1 + x));    /* row address */
 
 #if defined(RT_ACCUMULATE_ON)
           if (scene->accum_count) {
-            primary.randval =  tea4(x + (y*scene->hres), scene->accum_count);
+            primary.randval =  tea4(idx, scene->accum_count);
           }
 #endif
 
+          primary.idx = idx;        /* used for idx-based RNG seeding */
           primary.frng = cachefrng; /* each pixel uses the same AO RNG seed */
           col=scene->camera.cam_ray(&primary, x, y);    /* generate ray */
 
@@ -471,12 +476,14 @@ void * thread_trace(thr_parms * t) {
     for (y=starty; y<=stopy; y+=yinc) {
       addr = hsize * (y - 1) + (3 * (startx - 1));    /* row address */
       for (x=startx; x<=stopx; x+=xinc,addr+=hskip) {
+        unsigned int idx = y*scene->hres + x;  /* 1-D pixel index */
 #if defined(RT_ACCUMULATE_ON)
         if (scene->accum_count) {
-          primary.randval =  tea4(x + (y*scene->hres), scene->accum_count);
+          primary.randval =  tea4(idx, scene->accum_count);
         }
 #endif
 
+        primary.idx = idx;        /* used for idx-based RNG seeding */
         primary.frng = cachefrng; /* each pixel uses the same AO RNG seed */
         col=scene->camera.cam_ray(&primary, x, y);    /* generate ray */ 
 
